
%ifos aix6.1 || %ifos aix7.1
%global p7build 1
%else
%global p7build 0
%endif

Summary: A utility for getting files from remote servers (FTP, HTTP, and others)
Name: curl 
Version: 7.71.0
%if %{p7build}
Release: 1.p7
%else
Release: 1
%endif
License: MIT
Group: Applications/Internet
Source0: http://curl.haxx.se/download/%{name}-%{version}.tar.bz2
Source1: http://curl.haxx.se/download/%{name}-%{version}.tar.bz2.asc
Source2: curlbuild.h
Patch0: %{name}-%{version}-aix.patch
URL: http://curl.haxx.se/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

%if %{p7build}
BuildRequires: openssl-devel >= 1.0.2u-1.p7
%else
BuildRequires: openssl-devel >= 1.0.2u-1
%endif
BuildRequires: make
BuildRequires: openldap-devel >= 2.4.44-0.1
BuildRequires: pkg-config
BuildRequires: zlib-devel >= 1.2.3-7

%if %{p7build}
Requires:      openssl >= 1.0.2u-1.p7
%else
Requires:      openssl >= 1.0.2u-1
%endif
Requires:      openldap >= 2.4.44-0.1
Requires:      pkg-config
Requires:      zlib >= 1.2.3-7

%if %{p7build}
%ifos aix6.1
Requires: AIX-rpm >= 6.1.8.0
%endif
%ifos aix7.1
Requires: AIX-rpm >= 7.1.3.0
%endif
%endif

%define _libdir64 %{_prefix}/lib64

%description
cURL is a tool for getting files from FTP, HTTP, Gopher, Telnet, and
Dict servers, using any of the supported protocols. cURL is designed
to work without user interaction or any kind of interactivity. cURL
offers many useful capabilities, like proxy support, user
authentication, FTP upload, HTTP post, and file transfer resume.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Files needed for building applications with libcurl
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
%if %{p7build}
Requires: openssl-devel >= 1.0.2u-1.p7
%else
Requires: openssl-devel >= 1.0.2u-1
%endif
Requires: openldap-devel >= 2.4.44-0.1
Requires: pkg-config
Requires: zlib-devel >= 1.2.3-7

%description devel
cURL is a tool for getting files from FTP, HTTP, Gopher, Telnet, and
Dict servers, using any of the supported protocols. The curl-devel
package includes files needed for developing applications which can
use cURL's capabilities internally.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".


%prep
%setup -q 
%patch0
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export CONFIG_SHELL=/usr/bin/ksh
export CONFIG_ENV_ARGS=/usr/bin/ksh

export RM="/usr/bin/rm -f"

export CC="xlc_r"

export CFLAGS="-qmaxmem=262144 -O3 -qstrict -D_LARGE_FILES"
export CPPFLAGS="-D_LARGE_FILES -DSYSV -D_AIX -D_AIX32 -D_AIX41 -D_AIX43 -D_AIX51 -D_ALL_SOURCE -DFUNCPROTO=15 -I/opt/freeware/include"

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static \
    --enable-manual
gmake %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static \
    --enable-manual
gmake %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
gmake DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
gmake DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

# install the documentation
cd docs/libcurl
gmake DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}.a ${RPM_BUILD_ROOT}%{_libdir64}/lib%{name}.so*

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc 32bit/CHANGES 32bit/README* 32bit/COPYING
%doc 32bit/docs/BUGS 32bit/docs/FAQ 32bit/docs/FEATURES
%doc 32bit/docs/MANUAL 32bit/docs/RESOURCES
%doc 32bit/docs/TheArtOfHttpScripting 32bit/docs/TODO
%{_bindir}/curl
%{_bindir}/curl_64
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
%{_mandir}/man1/curl.1
/usr/bin/curl
/usr/bin/curl_64
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files devel
%defattr(-,root,system)
%doc 32bit/docs/examples/*.c 32bit/docs/examples/Makefile.example
%{_bindir}/curl-config*
%{_includedir}/%{name}
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/pkgconfig/*.pc
%{_libdir64}/pkgconfig/*.pc
%{_mandir}/man1/curl-config.1
%{_mandir}/man3/*
%{_datadir}/aclocal/libcurl.m4
/usr/bin/curl-config*
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%changelog
* Wed Jul 29 2020 Michael Perzl <michael@perzl.org> - 7.71.0-1
- updated to version 7.71.0

* Tue May 05 2020 Michael Perzl <michael@perzl.org> - 7.70.0-1
- updated to version 7.70.0

* Mon Apr 27 2020 Michael Perzl <michael@perzl.org> - 7.69.1-1
- updated to version 7.69.1

* Mon Apr 27 2020 Michael Perzl <michael@perzl.org> - 7.69.0-1
- updated to version 7.69.0

* Thu Jan 09 2020 Michael Perzl <michael@perzl.org> - 7.68.0-1
- updated to version 7.68.0

* Mon Dec 09 2019 Michael Perzl <michael@perzl.org> - 7.67.0-1
- updated to version 7.67.0

* Thu Sep 12 2019 Michael Perzl <michael@perzl.org> - 7.66.0-1
- updated to version 7.66.0

* Tue Jul 23 2019 Michael Perzl <michael@perzl.org> - 7.65.3-1
- updated to version 7.65.3

* Tue Jul 23 2019 Michael Perzl <michael@perzl.org> - 7.65.2-1
- updated to version 7.65.2

* Wed Jun 05 2019 Michael Perzl <michael@perzl.org> - 7.65.1-1
- updated to version 7.65.1

* Mon May 27 2019 Michael Perzl <michael@perzl.org> - 7.65.0-1
- updated to version 7.65.0

* Sat Apr 20 2019 Michael Perzl <michael@perzl.org> - 7.64.1-1
- updated to version 7.64.1

* Wed Feb 06 2019 Michael Perzl <michael@perzl.org> - 7.64.0-1
- updated to version 7.64.0

* Wed Jan 09 2019 Michael Perzl <michael@perzl.org> - 7.63.0-1
- updated to version 7.63.0

* Fri Nov 02 2018 Michael Perzl <michael@perzl.org> - 7.62.0-1
- updated to version 7.62.0

* Wed Sep 19 2018 Michael Perzl <michael@perzl.org> - 7.61.1-1
- updated to version 7.61.1

* Tue Jul 17 2018 Michael Perzl <michael@perzl.org> - 7.61.0-1
- updated to version 7.61.0

* Wed Jun 06 2018 Michael Perzl <michael@perzl.org> - 7.60.0-1
- updated to version 7.60.0

* Wed Jun 06 2018 Michael Perzl <michael@perzl.org> - 7.59.0-1
- updated to version 7.59.0

* Wed Jan 24 2018 Michael Perzl <michael@perzl.org> - 7.58.0-1
- updated to version 7.58.0

* Mon Dec 04 2017 Michael Perzl <michael@perzl.org> - 7.57.0-1
- updated to version 7.57.0

* Wed Oct 25 2017 Michael Perzl <michael@perzl.org> - 7.56.1-1
- updated to version 7.56.1

* Fri Oct 06 2017 Michael Perzl <michael@perzl.org> - 7.56.0-1
- updated to version 7.56.0

* Wed Aug 09 2017 Michael Perzl <michael@perzl.org> - 7.55.1-1
- updated to version 7.55.1

* Wed Aug 09 2017 Michael Perzl <michael@perzl.org> - 7.55.0-1
- updated to version 7.55.0

* Thu Jun 22 2017 Michael Perzl <michael@perzl.org> - 7.54.1-1
- updated to version 7.54.1

* Mon Apr 24 2017 Michael Perzl <michael@perzl.org> - 7.54.0-1
- updated to version 7.54.0

* Mon Feb 27 2017 Michael Perzl <michael@perzl.org> - 7.53.1-1
- updated to version 7.53.1

* Thu Feb 23 2017 Michael Perzl <michael@perzl.org> - 7.53.0-1
- updated to version 7.53.0

* Mon Jan 02 2017 Michael Perzl <michael@perzl.org> - 7.52.1-1
- updated to version 7.52.1

* Mon Jan 02 2017 Michael Perzl <michael@perzl.org> - 7.52.0-1
- updated to version 7.52.0

* Wed Nov 16 2016 Michael Perzl <michael@perzl.org> - 7.51.0-1
- updated to version 7.51.0

* Tue Sep 20 2016 Michael Perzl <michael@perzl.org> - 7.50.3-1
- updated to version 7.50.3

* Tue Sep 13 2016 Michael Perzl <michael@perzl.org> - 7.50.2-1
- updated to version 7.50.2

* Thu Aug 25 2016 Michael Perzl <michael@perzl.org> - 7.50.1-1
- updated to version 7.50.1

* Thu Aug 25 2016 Michael Perzl <michael@perzl.org> - 7.50.0-1
- updated to version 7.50.0

* Mon May 30 2016 Michael Perzl <michael@perzl.org> - 7.49.1-1
- updated to version 7.49.1

* Mon May 23 2016 Michael Perzl <michael@perzl.org> - 7.49.0-1
- updated to version 7.49.0

* Mon May 23 2016 Michael Perzl <michael@perzl.org> - 7.48.0-1
- updated to version 7.48.0

* Mon Mar 07 2016 Michael Perzl <michael@perzl.org> - 7.47.1-1
- updated to version 7.47.1

* Fri Mar 04 2016 Michael Perzl <michael@perzl.org> - 7.47.0-2
- recompiled against latest versions

* Thu Feb 04 2016 Michael Perzl <michael@perzl.org> - 7.47.0-1
- updated to version 7.47.0

* Wed Dec 23 2015 Michael Perzl <michael@perzl.org> - 7.46.0-1
- updated to version 7.46.0

* Wed Dec 23 2015 Michael Perzl <michael@perzl.org> - 7.45.0-1
- updated to version 7.45.0

* Wed Aug 26 2015 Michael Perzl <michael@perzl.org> - 7.44.0-1
- updated to version 7.44.0

* Wed Aug 26 2015 Michael Perzl <michael@perzl.org> - 7.43.0-1
- updated to version 7.43.0

* Wed Aug 26 2015 Michael Perzl <michael@perzl.org> - 7.42.0-1
- updated to version 7.42.0

* Wed Aug 26 2015 Michael Perzl <michael@perzl.org> - 7.41.0-1
- updated to version 7.41.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.40.0-1
- updated to version 7.40.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.39.0-1
- updated to version 7.39.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.38.0-1
- updated to version 7.38.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.37.0-1
- updated to version 7.37.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.36.0-1
- updated to version 7.36.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.35.0-1
- updated to version 7.35.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.34.0-1
- updated to version 7.34.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.33.0-1
- updated to version 7.33.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.32.0-1
- updated to version 7.32.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.31.0-1
- updated to version 7.31.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.30.0-1
- updated to version 7.30.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.29.0-1
- updated to version 7.29.0

* Tue Feb 03 2015 Michael Perzl <michael@perzl.org> - 7.28.1-1
- updated to version 7.28.1

* Thu Jan 29 2015 Michael Perzl <michael@perzl.org> - 7.28.0-1
- updated to version 7.28.0

* Tue Aug 29 2012 Michael Perzl <michael@perzl.org> - 7.27.0-1
- updated to version 7.27.0

* Mon Jun 04 2012 Michael Perzl <michael@perzl.org> - 7.26.0-2
- rebuilt against correct version of openssl

* Mon Jun 04 2012 Michael Perzl <michael@perzl.org> - 7.26.0-2
- rebuilt against correct version of openssl

* Tue May 29 2012 Michael Perzl <michael@perzl.org> - 7.26.0-1
- updated to version 7.26.0

* Tue Mar 27 2012 Michael Perzl <michael@perzl.org> - 7.25.0-1
- updated to version 7.25.0

* Wed Feb 08 2012 Michael Perzl <michael@perzl.org> - 7.24.0-2
- fixed compile against wrong openssl version

* Fri Jan 27 2012 Michael Perzl <michael@perzl.org> - 7.24.0-1
- updated to version 7.24.0

* Tue Nov 22 2011 Michael Perzl <michael@perzl.org> - 7.23.1-1
- updated to version 7.23.1

* Tue Nov 22 2011 Michael Perzl <michael@perzl.org> - 7.22.0-1
- updated to version 7.22.0

* Tue Nov 22 2011 Michael Perzl <michael@perzl.org> - 7.21.7-1
- updated to version 7.21.7

* Tue Dec 21 2010 Michael Perzl <michael@perzl.org> - 7.21.3-1
- updated to version 7.21.3

* Wed Oct 13 2010 Michael Perzl <michael@perzl.org> - 7.21.2-1
- updated to version 7.21.2

* Thu Aug 12 2010 Michael Perzl <michael@perzl.org> - 7.21.1-1
- updated to version 7.21.1

* Wed Jun 16 2010 Michael Perzl <michael@perzl.org> - 7.21.0-1
- updated to version 7.21.0

* Fri Apr 16 2010 Michael Perzl <michael@perzl.org> - 7.20.1-1
- updated to version 7.20.1

* Thu Feb 11 2010 Michael Perzl <michael@perzl.org> - 7.20.0-1
- updated to version 7.20.0

* Thu Nov 05 2009 Michael Perzl <michael@perzl.org> - 7.19.7-1
- updated to version 7.19.7

* Mon Sep 21 2009 Michael Perzl <michael@perzl.org> - 7.19.6-2
- fixed a 64-bit header file issue

* Mon Aug 17 2009 Michael Perzl <michael@perzl.org> - 7.19.6-1
- updated to version 7.19.6

* Tue Jun 16 2009 Michael Perzl <michael@perzl.org> - 7.19.5-1
- updated to version 7.19.5

* Fri Mar 20 2009 Michael Perzl <michael@perzl.org> - 7.19.4-1
- updated to version 7.19.4

* Tue Jan 20 2009 Michael Perzl <michael@perzl.org> - 7.19.3-1
- updated to version 7.19.3

* Fri Nov 14 2008 Michael Perzl <michael@perzl.org> - 7.19.2-1
- updated to version 7.19.2

* Thu Nov 06 2008 Michael Perzl <michael@perzl.org> - 7.19.1-1
- updated to version 7.19.1

* Tue Sep 02 2008 Michael Perzl <michael@perzl.org> - 7.19.0-1
- updated to version 7.19.0

* Tue Jun 24 2008 Michael Perzl <michael@perzl.org> - 7.18.2-1
- updated to version 7.18.2 and built against new OpenSSL

* Mon Mar 31 2008 Michael Perzl <michael@perzl.org> - 7.18.1-1
- updated to version 7.18.1

* Tue Feb 19 2008 Michael Perzl <michael@perzl.org> - 7.18.0-1
- updated to version 7.18.0

* Fri Dec 28 2007 Michael Perzl <michael@perzl.org> - 7.17.1-1
- first version for AIX V5.1 and higher
